using Microsoft.AspNetCore.Builder;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using StackExchange.Redis;
using Wisej.Core;
using Wisej.Web;

namespace WisejWebDesktopAppQueue {
    /// <summary>
    /// The Startup class configures services and the app's request pipeline.
    /// For more information on how to configure your application, visit https://go.microsoft.com/fwlink/?LinkID=398940.
    /// </summary>
    public class Startup {
        public Startup(IConfiguration configuration) {
            Configuration = configuration;
        }
        public IConfiguration Configuration { get; }

        public static void Main(string[] args) {
            var builder = WebApplication.CreateBuilder(new WebApplicationOptions {
                Args = args,
                WebRootPath = "./"
            });

            Application.Services.AddService<IConnectionMultiplexer>(
                 x => ConnectionMultiplexer.Connect("localhost:6379")
            );

            using IHost host = Host.CreateDefaultBuilder(args)
            .ConfigureServices(services => {
                services.AddHostedService<RedisSubscriver>();
            })
            .Build();

            host.RunAsync();

            var app = builder.Build();
            app.UseWisej();
            app.UseFileServer();
            app.Run();
        }
    }
   
}
